import os
import sys

sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
import dpdata
import dpdata.gaussian.gjf
import dpdata.md.msd
import dpdata.md.water
import dpdata.stat
import dpdata.system
